# NRGTEN
Najmanovich Research Group Toolkit for Elastic Networks

If you use NRGTEN, please cite this paper: `reference to NRGTEN`

The NRGTEN documentation is hosted here: https://nrgten.readthedocs.io/en/latest
